Struct ExtBackgroundEffectSurfaceV1
pub struct ExtBackgroundEffectSurfaceV1 { /* private fields */ }wayland and Linux only.Expand description
background effects for a surface
The background effect object provides a way to specify a region behind a surface that should have background effects like blur applied.
If the wl_surface associated with the ext_background_effect_surface_v1 object has been destroyed, this object becomes inert.
This interface has no events.
Implementations
impl ExtBackgroundEffectSurfaceV1
impl ExtBackgroundEffectSurfaceV1
pub fn destroy(&self)
pub fn destroy(&self)
release the blur object
Informs the server that the client will no longer be using this protocol object. The effect regions will be removed on the next commit.
pub fn set_blur_region(&self, region: Option<&WlRegion>)
pub fn set_blur_region(&self, region: Option<&WlRegion>)
set blur region
This request sets the region of the surface that will have its background blurred.
The blur region is specified in the surface-local coordinates, and clipped by the compositor to the surface size.
The initial value for the blur region is empty. Setting the pending blur region has copy semantics, and the wl_region object can be destroyed immediately. A NULL wl_region removes the effect.
The blur region is double-buffered state, and will be applied on the next wl_surface.commit.
The blur algorithm is subject to compositor policies.
If the associated surface has been destroyed, the surface_destroyed error will be raised.